@@ -8,7 +8,7 @@ from sql_models.shared.role.Role import Role
 class RoleVisibility(SQLCamelModel):
     visibility: Role | None = Field(
         default=None,
-        sa_column=Column(Enum),
+        sa_column=Column(Enum(Role)),
     )
 
 
